@@ -3,9 +3,9 @@ INSERT INTO network (userid, networkname, identityid, servercodec, encodingcodec
                      autoidentifypassword, useautoreconnect, autoreconnectinterval,
                      autoreconnectretries, unlimitedconnectretries, rejoinchannels, usesasl,
                      saslaccount, saslpassword, usecustomessagerate, messagerateburstsize,
-                     messageratedelay, unlimitedmessagerate)
+                     messageratedelay, unlimitedmessagerate, skipcaps)
 VALUES (:userid, :networkname, :identityid, :servercodec, :encodingcodec, :decodingcodec,
         :userandomserver, :perform, :useautoidentify, :autoidentifyservice, :autoidentifypassword,
         :useautoreconnect, :autoreconnectinterval, :autoreconnectretries, :unlimitedconnectretries,
         :rejoinchannels, :usesasl, :saslaccount, :saslpassword, :usecustomessagerate,
-        :messagerateburstsize, :messageratedelay, :unlimitedmessagerate)
+        :messagerateburstsize, :messageratedelay, :unlimitedmessagerate, :skipcaps)
