@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2005-2019 by the Quassel Project                        *
+ *   Copyright (C) 2005-2022 by the Quassel Project                        *
  *   devel@quassel-irc.org                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -24,28 +24,32 @@
 
 #include "corenetwork.h"
 #include "eventmanager.h"
+#include "ircdecoder.h"
 #include "ircevent.h"
+#include "irctags.h"
 #include "messageevent.h"
 #include "networkevent.h"
 
 #ifdef HAVE_QCA2
-#  include "cipher.h"
-#  include "keyevent.h"
+#    include "cipher.h"
+#    include "keyevent.h"
 #endif
 
-IrcParser::IrcParser(CoreSession *session) :
-    QObject(session),
-    _coreSession(session)
+IrcParser::IrcParser(CoreSession* session)
+    : QObject(session)
+    , _coreSession(session)
 {
     // Check if raw IRC logging is enabled
     _debugLogRawIrc = (Quassel::isOptionSet("debug-irc") || Quassel::isOptionSet("debug-irc-id"));
     _debugLogRawNetId = Quassel::optionValue("debug-irc-id").toInt();
+    // Check if parsed IRC logging is enabled
+    _debugLogParsedIrc = (Quassel::isOptionSet("debug-irc-parsed") || Quassel::isOptionSet("debug-irc-parsed-id"));
+    _debugLogParsedNetId = Quassel::optionValue("debug-irc-parsed-id").toInt();
 
-    connect(this, SIGNAL(newEvent(Event *)), coreSession()->eventManager(), SLOT(postEvent(Event *)));
+    connect(this, &IrcParser::newEvent, coreSession()->eventManager(), &EventManager::postEvent);
 }
 
-
-bool IrcParser::checkParamCount(const QString &cmd, const QList<QByteArray> &params, int minParams)
+bool IrcParser::checkParamCount(const QString& cmd, const QList<QByteArray>& params, int minParams)
 {
     if (params.count() < minParams) {
         qWarning() << "Expected" << minParams << "params for IRC command" << cmd << ", got:" << params;
@@ -54,8 +58,7 @@ bool IrcParser::checkParamCount(const QString &cmd, const QList<QByteArray> &par
     return true;
 }
 
-
-QByteArray IrcParser::decrypt(Network *network, const QString &bufferName, const QByteArray &message, bool isTopic)
+QByteArray IrcParser::decrypt(Network* network, const QString& bufferName, const QByteArray& message, bool isTopic)
 {
 #ifdef HAVE_QCA2
     if (message.isEmpty())
@@ -64,7 +67,7 @@ QByteArray IrcParser::decrypt(Network *network, const QString &bufferName, const
     if (!Cipher::neededFeaturesAvailable())
         return message;
 
-    Cipher *cipher = qobject_cast<CoreNetwork *>(network)->cipher(bufferName);
+    Cipher* cipher = qobject_cast<CoreNetwork*>(network)->cipher(bufferName);
     if (!cipher || cipher->key().isEmpty())
         return message;
 
@@ -77,12 +80,11 @@ QByteArray IrcParser::decrypt(Network *network, const QString &bufferName, const
 #endif
 }
 
-
 /* parse the raw server string and generate an appropriate event */
 /* used to be handleServerMsg()                                  */
-void IrcParser::processNetworkIncoming(NetworkDataEvent *e)
+void IrcParser::processNetworkIncoming(NetworkDataEvent* e)
 {
-    CoreNetwork *net = qobject_cast<CoreNetwork *>(e->network());
+    auto* net = qobject_cast<CoreNetwork*>(e->network());
     if (!net) {
         qWarning() << "Received network event without valid network pointer!";
         return;
@@ -91,91 +93,85 @@ void IrcParser::processNetworkIncoming(NetworkDataEvent *e)
     // note that the IRC server is still alive
     net->resetPingTimeout();
 
-    QByteArray msg = e->data();
-    if (msg.isEmpty()) {
+    const QByteArray rawMsg = e->data();
+    if (rawMsg.isEmpty()) {
         qWarning() << "Received empty string from server!";
         return;
     }
 
     // Log the message if enabled and network ID matches or allows all
-    if (_debugLogRawIrc
-            && (_debugLogRawNetId == -1 || net->networkId().toInt() == _debugLogRawNetId)) {
+    if (_debugLogRawIrc && (_debugLogRawNetId == -1 || net->networkId().toInt() == _debugLogRawNetId)) {
         // Include network ID
-        qDebug() << "IRC net" << net->networkId() << "<<" << msg;
+        qDebug() << "IRC net" << net->networkId() << "<<" << rawMsg;
     }
 
-    // Now we split the raw message into its various parts...
+    QHash<IrcTagKey, QString> tags;
     QString prefix;
-    QByteArray trailing;
-    QString cmd, target;
+    QString cmd;
+    QList<QByteArray> params;
+    IrcDecoder::parseMessage([&net](const QByteArray& data) {
+        return net->serverDecode(data);
+    }, rawMsg, tags, prefix, cmd, params);
 
-    // First, check for a trailing parameter introduced by " :", since this might screw up splitting the msg
-    // NOTE: This assumes that this is true in raw encoding, but well, hopefully there are no servers running in japanese on protocol level...
-    int idx = msg.indexOf(" :");
-    if (idx >= 0) {
-        if (msg.length() > idx + 2)
-            trailing = msg.mid(idx + 2);
-        msg = msg.left(idx);
-    }
-    // OK, now it is safe to split...
-    QList<QByteArray> params = msg.split(' ');
-
-    // This could still contain empty elements due to (faulty?) ircds sending multiple spaces in a row
-    // Also, QByteArray is not nearly as convenient to work with as QString for such things :)
-    QList<QByteArray>::iterator iter = params.begin();
-    while (iter != params.end()) {
-        if (iter->isEmpty())
-            iter = params.erase(iter);
-        else
-            ++iter;
+    // Log the message if enabled and network ID matches or allows all
+    if (_debugLogParsedIrc && (_debugLogParsedNetId == -1 || net->networkId().toInt() == _debugLogParsedNetId)) {
+        // Include network ID
+        qDebug() << "IRC net" << net->networkId() << "<<" << tags << prefix << cmd << params;
     }
 
-    if (!trailing.isEmpty())
-        params << trailing;
-    if (params.count() < 1) {
-        qWarning() << "Received invalid string from server!";
-        return;
-    }
-
-    QString foo = net->serverDecode(params.takeFirst());
-
-    // a colon as the first chars indicates the existence of a prefix
-    if (foo[0] == ':') {
-        foo.remove(0, 1);
-        prefix = foo;
-        if (params.count() < 1) {
-            qWarning() << "Received invalid string from server!";
-            return;
+    if (net->capEnabled(IrcCap::SERVER_TIME) && tags.contains(IrcTags::SERVER_TIME)) {
+        QDateTime serverTime = QDateTime::fromString(tags[IrcTags::SERVER_TIME], "yyyy-MM-ddThh:mm:ss.zzzZ");
+        serverTime.setTimeSpec(Qt::UTC);
+        if (serverTime.isValid()) {
+            e->setTimestamp(serverTime);
+        } else {
+            qDebug() << "Invalid timestamp from server-time tag:" << tags[IrcTags::SERVER_TIME];
         }
-        foo = net->serverDecode(params.takeFirst());
     }
 
-    // next string without a whitespace is the command
-    cmd = foo.trimmed();
+    if (net->capEnabled(IrcCap::ACCOUNT_TAG) && tags.contains(IrcTags::ACCOUNT)) {
+        // Whenever account-tag is specified, update the relevant IrcUser if it exists
+        // Logged-out status is handled in specific commands (PRIVMSG, NOTICE, etc)
+        //
+        // Don't use "updateNickFromMask" here to ensure this only updates existing IrcUsers and
+        // won't create a new IrcUser.  This guards against an IRC server setting "account" tag in
+        // nonsensical places, e.g. for messages that are not user sent.
+        IrcUser* ircuser = net->ircUser(prefix);
+        if (ircuser) {
+            ircuser->setAccount(tags[IrcTags::ACCOUNT]);
+        }
 
-    QList<Event *> events;
+        // NOTE: if "account-tag" is enabled and no "account" tag is sent, the given user isn't
+        // logged in ONLY IF it is a user-initiated command.  Quassel follows a mixture of what
+        // other clients do here - only marking as logged out via PRIVMSG/NOTICE, but marking logged
+        // in via any message.
+        //
+        // See https://ircv3.net/specs/extensions/account-tag-3.2
+    }
+
+    QList<Event*> events;
     EventManager::EventType type = EventManager::Invalid;
 
+    QString messageTarget;
     uint num = cmd.toUInt();
     if (num > 0) {
         // numeric reply
         if (params.count() == 0) {
-            qWarning() << "Message received from server violates RFC and is ignored!" << msg;
+            qWarning() << "Message received from server violates RFC and is ignored!" << rawMsg;
             return;
         }
         // numeric replies have the target as first param (RFC 2812 - 2.4). this is usually our own nick. Remove this!
-        target = net->serverDecode(params.takeFirst());
+        messageTarget = net->serverDecode(params.takeFirst());
         type = EventManager::IrcEventNumeric;
     }
     else {
         // any other irc command
         QString typeName = QLatin1String("IrcEvent") + cmd.at(0).toUpper() + cmd.mid(1).toLower();
-        type = eventManager()->eventTypeByName(typeName);
+        type = EventManager::eventTypeByName(typeName);
         if (type == EventManager::Invalid) {
-            type = eventManager()->eventTypeByName("IrcEventUnknown");
+            type = EventManager::eventTypeByName("IrcEventUnknown");
             Q_ASSERT(type != EventManager::Invalid);
         }
-        target = QString();
     }
 
     // Almost always, all params are server-encoded. There's a few exceptions, let's catch them here!
@@ -185,15 +181,32 @@ void IrcParser::processNetworkIncoming(NetworkDataEvent *e)
     // nice pre-parsed events that the CTCP handler can consume.
 
     QStringList decParams;
-    bool defaultHandling = true; // whether to automatically copy the remaining params and send the event
+    bool defaultHandling = true;  // whether to automatically copy the remaining params and send the event
 
     switch (type) {
     case EventManager::IrcEventPrivmsg:
-        defaultHandling = false; // this might create a list of events
+        defaultHandling = false;  // this might create a list of events
 
         if (checkParamCount(cmd, params, 1)) {
             QString senderNick = nickFromMask(prefix);
-            net->updateNickFromMask(prefix);
+            // Fetch/create the relevant IrcUser, and store it for later updates
+            IrcUser* ircuser = net->updateNickFromMask(prefix);
+
+            // Handle account-tag
+            if (ircuser && net->capEnabled(IrcCap::ACCOUNT_TAG)) {
+                if (tags.contains(IrcTags::ACCOUNT)) {
+                    // Account tag available, set account.
+                    // This duplicates the generic account-tag handling in case a new IrcUser object
+                    // was just created.
+                    ircuser->setAccount(tags[IrcTags::ACCOUNT]);
+                }
+                else {
+                    // PRIVMSG is user sent; it's safe to assume the user has logged out.
+                    // "*" is used to represent logged-out.
+                    ircuser->setAccount("*");
+                }
+            }
+
             // Check if the sender is our own nick.  If so, treat message as if sent by ourself.
             // See http://ircv3.net/specs/extensions/echo-message-3.2.html
             // Cache the result to avoid multiple redundant comparisons
@@ -211,7 +224,13 @@ void IrcParser::processNetworkIncoming(NetworkDataEvent *e)
                 // consider including this within an if (!isSelfMessage) block
                 msg = decrypt(net, target, msg);
 
-                IrcEventRawMessage *rawMessage = new IrcEventRawMessage(EventManager::IrcEventRawPrivmsg, net, msg, prefix, target, e->timestamp());
+                IrcEventRawMessage* rawMessage = new IrcEventRawMessage(EventManager::IrcEventRawPrivmsg,
+                                                                        net,
+                                                                        tags,
+                                                                        msg,
+                                                                        prefix,
+                                                                        target,
+                                                                        e->timestamp());
                 if (isSelfMessage) {
                     // Self-messages need processed differently, tag as such via flag.
                     rawMessage->setFlag(EventManager::Self);
@@ -230,20 +249,25 @@ void IrcParser::processNetworkIncoming(NetworkDataEvent *e)
             // Cache the result to avoid multiple redundant comparisons
             bool isSelfMessage = net->isMyNick(nickFromMask(prefix));
 
+            // Only update from the prefix once during the loop
+            bool updatedFromPrefix = false;
+
             QStringList targets = net->serverDecode(params.at(0)).split(',', QString::SkipEmptyParts);
             QStringList::const_iterator targetIter;
             for (targetIter = targets.constBegin(); targetIter != targets.constEnd(); ++targetIter) {
                 QString target = *targetIter;
 
                 // special treatment for welcome messages like:
-                // :ChanServ!ChanServ@services. NOTICE egst :[#apache] Welcome, this is #apache. Please read the in-channel topic message. This channel is being logged by IRSeekBot. If you have any question please see http://blog.freenode.net/?p=68
+                // :ChanServ!ChanServ@services. NOTICE egst :[#apache] Welcome, this is #apache. Please read the in-channel topic message.
+                // This channel is being logged by IRSeekBot. If you have any question please see http://blog.freenode.net/?p=68
                 if (!net->isChannelName(target)) {
                     QString decMsg = net->serverDecode(params.at(1));
-                    QRegExp welcomeRegExp("^\\[([^\\]]+)\\] ");
+                    QRegExp welcomeRegExp(R"(^\[([^\]]+)\] )");
                     if (welcomeRegExp.indexIn(decMsg) != -1) {
                         QString channelname = welcomeRegExp.cap(1);
                         decMsg = decMsg.mid(welcomeRegExp.matchedLength());
-                        CoreIrcChannel *chan = static_cast<CoreIrcChannel *>(net->ircChannel(channelname)); // we only have CoreIrcChannels in the core, so this cast is safe
+                        // we only have CoreIrcChannels in the core, so this cast is safe
+                        CoreIrcChannel* chan = static_cast<CoreIrcChannel*>(net->ircChannel(channelname)); // NOLINT(cppcoreguidelines-pro-type-static-cast-downcast)
                         if (chan && !chan->receivedWelcomeMsg()) {
                             chan->setReceivedWelcomeMsg();
                             events << new MessageEvent(Message::Notice, net, decMsg, prefix, channelname, Message::None, e->timestamp());
@@ -264,7 +288,29 @@ void IrcParser::processNetworkIncoming(NetworkDataEvent *e)
                         if (!isSelfMessage) {
                             target = nickFromMask(prefix);
                         }
-                        net->updateNickFromMask(prefix);
+
+                        if (!updatedFromPrefix) {
+                            // Don't repeat this within the loop, the prefix doesn't change
+                            updatedFromPrefix = true;
+
+                            // Fetch/create the relevant IrcUser, and store it for later updates
+                            IrcUser* ircuser = net->updateNickFromMask(prefix);
+
+                            // Handle account-tag
+                            if (ircuser && net->capEnabled(IrcCap::ACCOUNT_TAG)) {
+                                if (tags.contains(IrcTags::ACCOUNT)) {
+                                    // Account tag available, set account.
+                                    // This duplicates the generic account-tag handling in case a
+                                    // new IrcUser object was just created.
+                                    ircuser->setAccount(tags[IrcTags::ACCOUNT]);
+                                }
+                                else {
+                                    // NOTICE is user sent; it's safe to assume the user has
+                                    // logged out.  "*" is used to represent logged-out.
+                                    ircuser->setAccount("*");
+                                }
+                            }
+                        }
                     }
                 }
 
@@ -273,13 +319,21 @@ void IrcParser::processNetworkIncoming(NetworkDataEvent *e)
                 // Don't allow key exchange in channels, and don't allow it for self-messages.
                 bool keyExchangeAllowed = (!net->isChannelName(target) && !isSelfMessage);
                 if (params[1].startsWith("DH1080_INIT") && keyExchangeAllowed) {
-                    events << new KeyEvent(EventManager::KeyEvent, net, prefix, target, KeyEvent::Init, params[1].mid(12));
-                } else if (params[1].startsWith("DH1080_FINISH") && keyExchangeAllowed) {
-                    events << new KeyEvent(EventManager::KeyEvent, net, prefix, target, KeyEvent::Finish, params[1].mid(14));
-                } else
+                    events << new KeyEvent(EventManager::KeyEvent, net, tags, prefix, target, KeyEvent::Init, params[1].mid(12));
+                }
+                else if (params[1].startsWith("DH1080_FINISH") && keyExchangeAllowed) {
+                    events << new KeyEvent(EventManager::KeyEvent, net, tags, prefix, target, KeyEvent::Finish, params[1].mid(14));
+                }
+                else
 #endif
                 {
-                    IrcEventRawMessage *rawMessage = new IrcEventRawMessage(EventManager::IrcEventRawNotice, net, params[1], prefix, target, e->timestamp());
+                    IrcEventRawMessage* rawMessage = new IrcEventRawMessage(EventManager::IrcEventRawNotice,
+                                                                            net,
+                                                                            tags,
+                                                                            params[1],
+                                                                            prefix,
+                                                                            target,
+                                                                            e->timestamp());
                     if (isSelfMessage) {
                         // Self-messages need processed differently, tag as such via flag.
                         rawMessage->setFlag(EventManager::Self);
@@ -290,11 +344,11 @@ void IrcParser::processNetworkIncoming(NetworkDataEvent *e)
         }
         break;
 
-    // the following events need only special casing for param decoding
+        // the following events need only special casing for param decoding
     case EventManager::IrcEventKick:
-        if (params.count() >= 3) { // we have a reason
+        if (params.count() >= 3) {  // we have a reason
             decParams << net->serverDecode(params.at(0)) << net->serverDecode(params.at(1));
-            decParams << net->channelDecode(decParams.first(), params.at(2)); // kick reason
+            decParams << net->channelDecode(decParams.first(), params.at(2));  // kick reason
         }
         break;
 
@@ -314,6 +368,34 @@ void IrcParser::processNetworkIncoming(NetworkDataEvent *e)
         }
         break;
 
+    case EventManager::IrcEventTagmsg:
+        defaultHandling = false;  // this might create a list of events
+
+        if (checkParamCount(cmd, params, 1)) {
+            QString senderNick = nickFromMask(prefix);
+            net->updateNickFromMask(prefix);
+            // Check if the sender is our own nick.  If so, treat message as if sent by ourself.
+            // See http://ircv3.net/specs/extensions/echo-message-3.2.html
+            // Cache the result to avoid multiple redundant comparisons
+            bool isSelfMessage = net->isMyNick(senderNick);
+
+            QStringList targets = net->serverDecode(params.at(0)).split(',', QString::SkipEmptyParts);
+            QStringList::const_iterator targetIter;
+            for (targetIter = targets.constBegin(); targetIter != targets.constEnd(); ++targetIter) {
+                // For self-messages, keep the target, don't set it to the senderNick
+                QString target = net->isChannelName(*targetIter) || net->isStatusMsg(*targetIter) || isSelfMessage ? *targetIter : senderNick;
+
+                IrcEvent* tagMsg = new IrcEvent(EventManager::IrcEventTagmsg, net, tags, prefix, {target});
+                if (isSelfMessage) {
+                    // Self-messages need processed differently, tag as such via flag.
+                    tagMsg->setFlag(EventManager::Self);
+                }
+                tagMsg->setTimestamp(e->timestamp());
+                events << tagMsg;
+            }
+        }
+        break;
+
     case EventManager::IrcEventTopic:
         if (params.count() >= 1) {
             QString channel = net->serverDecode(params.at(0));
@@ -360,14 +442,18 @@ void IrcParser::processNetworkIncoming(NetworkDataEvent *e)
             }
             break;
         case 451: /* You have not registered... */
-            if (target.compare("CAP", Qt::CaseInsensitive) == 0) {
+            if (messageTarget.compare("CAP", Qt::CaseInsensitive) == 0) {
                 // :irc.server.com 451 CAP :You have not registered
                 // If server doesn't support capabilities, it will report this message.  Turn it
                 // into a nicer message since it's not a real error.
                 defaultHandling = false;
-                events << new MessageEvent(Message::Server, e->network(),
+                events << new MessageEvent(Message::Server,
+                                           e->network(),
                                            tr("Capability negotiation not supported"),
-                                           QString(), QString(), Message::None, e->timestamp());
+                                           QString(),
+                                           QString(),
+                                           Message::None,
+                                           e->timestamp());
             }
             break;
         }
@@ -385,17 +471,17 @@ void IrcParser::processNetworkIncoming(NetworkDataEvent *e)
         if (!decParams.isEmpty() && decParams.last().endsWith(' '))
             decParams.append(decParams.takeLast().trimmed());
 
-        IrcEvent *event;
+        IrcEvent* event;
         if (type == EventManager::IrcEventNumeric)
-            event = new IrcEventNumeric(num, net, prefix, target);
+            event = new IrcEventNumeric(num, net, tags, prefix, messageTarget);
         else
-            event = new IrcEvent(type, net, prefix);
+            event = new IrcEvent(type, net, tags, prefix);
         event->setParams(decParams);
         event->setTimestamp(e->timestamp());
         events << event;
     }
 
-    foreach(Event *event, events) {
+    for (Event* event : events) {
         emit newEvent(event);
     }
 }
